@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.57.2.1.2.29 $
+// $Revision: 1.57.2.1.2.31 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2013 RIKEN, Japan All rights reserved.                //
@@ -573,7 +573,7 @@ function xnpdataGetDetailInformationQuickSearchQuery( &$wheres, &$join, $keyword
   $data_experimenter_table = $xoopsDB->prefix( 'xnpdata_experimenter' );
   $file_table = $xoopsDB->prefix( 'xoonips_file' );
 
-  $join = " join $data_experimenter_table on ".$data_experimenter_table.'.data_id  = '.$xoopsDB->prefix( 'xoonips_item_basic' ).'.item_id ';
+  $join = " INNER JOIN $data_experimenter_table ON ".$data_experimenter_table.'.data_id  = '.$xoopsDB->prefix( 'xoonips_item_basic' ).'.item_id ';
   $wheres = xnpGetKeywordsQueries( array( "$data_experimenter_table.experimenter", "$file_table.caption" ), $keywords );
   return true;
 }
@@ -611,14 +611,18 @@ function xnpdataGetAdvancedSearchQuery( &$where, &$join ) {
   }
 
   if ( ! empty( $xnpdata_data_file ) ) {
-    list( $pattern, $errorMessage ) = xnpKeywordsToFulltextSql( $xnpdata_data_file );
-    if ( ! $errorMessage ) {
-      $wheres[] = "match ( $search_text_table.search_text ) against ( '$pattern' in boolean mode )";
-    }
+    $search_text_table = $xoopsDB->prefix('xoonips_search_text');
+    $file_table = $xoopsDB->prefix('xoonips_file');
+    $searchutil =& xoonips_getutility('search');
+    $fulltext_query = $xnpdata_data_file;
+    $fulltext_encoding = mb_detect_encoding($fulltext_query);
+    $fulltext_criteria = new CriteriaCompo($searchutil->getFulltextSearchCriteria('search_text', $fulltext_query, $fulltext_encoding, $search_text_table));
+    $fulltext_criteria->add(new Criteria('is_deleted', 0, '=', $file_table));
+    $wheres[] = $fulltext_criteria->render();
   }
 
-  $where = implode( ' and ', $wheres );
-  $join = " join $data_experimenter_table on ".$data_experimenter_table.'.data_id  = '.$xoopsDB->prefix( 'xoonips_item_basic' ).'.item_id ';
+  $where = implode( ' AND ', $wheres );
+  $join = " INNER JOIN $data_experimenter_table ON ".$data_experimenter_table.'.data_id  = '.$xoopsDB->prefix( 'xoonips_item_basic' ).'.item_id ';
 }
 
 function xnpdataGetAdvancedSearchBlock( &$search_var ) {
