@@ -9,7 +9,7 @@ CREATE TABLE xnpmodel_item_detail (
     `attachment_dl_limit` int(1) unsigned default 0,
     `attachment_dl_notify` int(1) unsigned default 0,
     PRIMARY KEY (model_id)
-) TYPE=InnoDB;
+) ENGINE=InnoDB;
 
 #
 # `xnpmodel_creator`
@@ -21,4 +21,4 @@ CREATE TABLE `xnpmodel_creator` (
   `creator` varchar(255) NOT NULL,
   `creator_order` int(10) unsigned NOT NULL default '0',
   PRIMARY KEY  (`model_creator_id`)
-) TYPE=InnoDB;
+) ENGINE=InnoDB;
