@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.14.2.1.2.24 $
+// $Revision: 1.14.2.1.2.27 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2013 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -854,85 +854,98 @@ function xnpsimulatorGetAttachmentDownloadNotifyOption( $item_id ) {
 }
 
 function xnpsimulatorSupportMetadataFormat( $metadataPrefix, $item_id ) {
-  if ( $metadataPrefix == 'oai_dc' || $metadataPrefix == 'junii' || $metadataPrefix == 'junii2' ) {
+  if ( $metadataPrefix == 'oai_dc' || $metadataPrefix == 'junii2' ) {
     return true;
   }
   return false;
 }
 
-function xnpsimulatorGetMetadata( $metadataPrefix, $item_id ) {
-  $textutil =& xoonips_getutility( 'text' );
-  $xnpsimulator_handler =& xoonips_getormcompohandler( 'xnpsimulator', 'item' );
-  $xnpsimulator =& $xnpsimulator_handler->get( $item_id );
-  if ( ! $xnpsimulator ) {
+function xnpsimulatorGetMetadata($prefix, $item_id) {
+  $mydirpath = dirname(dirname(__FILE__));
+  $mydirname = basename($mydirpath);
+  if (!in_array($prefix, array('oai_dc', 'junii2')))
     return false;
-  }
-
-  $meta_basic = xnpGetBasicInformationMetadata( $metadataPrefix, $item_id );
-  if ( ! $meta_basic ) {
+  // detail information 
+  $detail_handler =& xoonips_getormhandler($mydirname, 'item_detail');
+  $developer_handler =& xoonips_getormhandler($mydirname, 'developer');
+  $detail_obj =& $detail_handler->get($item_id);
+  if (empty($detail_obj))
     return false;
+  $detail = $detail_obj->getArray();
+  $criteria = new Criteria('simulator_id', $item_id);
+  $criteria->setSort('developer_order');
+  $developer_objs =& $developer_handler->getObjects($criteria);
+  $detail['developers'] = array();
+  foreach ($developer_objs as $developer_obj)
+    $detail['developers'][] = $developer_obj->get('developer');
+  $types = xnpsimulator_get_type_array();
+  $detail['simulator_type_display'] = $types[$detail['simulator_type']];
+  // basic information
+  $basic = xnpGetBasicInformationArray($item_id);
+  $basic['publication_date_iso8601'] = xnpISO8601($basic['publication_year'], $basic['publication_month'], $basic['publication_mday']);
+  // indexes
+  $indexes = array();
+  if (xnp_get_index_id_by_item_id($_SESSION['XNPSID'], $item_id, $xids) == RES_OK)
+    foreach ($xids as $xid)
+      if (xnp_get_index($_SESSION['XNPSID'], $xid, $index) == RES_OK)
+        $indexes[] = xnpGetIndexPathServerString($_SESSION['XNPSID'], $xid);
+  // files
+  $files = array();
+  $mimetypes = array();
+  $file_handler =& xoonips_gethandler('xoonips', 'file');
+  if ($detail['attachment_dl_limit'] == 0) {
+    $files = $file_handler->getFilesInfo($item_id, 'simulator_data');
+    foreach ($files as $file) {
+      if (!in_array($file['mime_type'], $mimetypes))
+        $mimetypes[] = $file['mime_type'];
+    }
   }
-
-  $basic =& $xnpsimulator->getVar( 'basic' );
-  $detail = xnpsimulatorGetDetailInformation( $item_id );
-  $lines = array();
-  if ( $metadataPrefix == 'junii' ) {
-    $lines[] = '<metadata>';
-    $lines[] = '<meta xmlns="http://metasv.nii.ac.jp/oai/"
-xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-xsi:schemaLocation="http://metasv.nii.ac.jp/oai http://metasv.nii.ac.jp/oai/junii.xsd">';
-    $lines[] = $meta_basic;
-    $lines[] = "<type xsi:type=\"NII\">".$textutil->xml_special_chars( xnpGetMetadataJunii( 22 ) ).'</type>';
-    $lines[] = '<type>simulatorType:'.$textutil->xml_special_chars( $detail['simulator_type']['value'] ).'</type>';
-    foreach ( $xnpsimulator->getVar( 'developer' ) as $developer ) {
-      $lines[] = '<creator>'.$textutil->xml_special_chars( $developer->getVar( 'developer', 'n' ) ).'</creator>';
-    }
-    $lines[] = "<date xsi:type=\"ISO8601\">".xnpISO8601( $basic->getVar( 'publication_year', 'n' ), $basic->getVar( 'publication_month', 'n' ), $basic->getVar( 'publication_mday', 'n' ) ).'</date>';
-    $lines[] = '<description>readme:'.$textutil->xml_special_chars( $detail['readme']['value'] ).'</description>';
-    $lines[] = '<description>rights:'.$textutil->xml_special_chars( $detail['rights']['value'] ).'</description>';
-    $lines[] = '</meta>';
-    $lines[] = '</metadata>';
-    return implode( "\n", $lines )."\n";
-  } else if ( $metadataPrefix == 'junii2' ) {
-    $lines[] = '<metadata>';
-    $lines[] = '<meta xmlns="http://metasv.nii.ac.jp/oai/"
-xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-xsi:schemaLocation="http://metasv.nii.ac.jp/oai http://metasv.nii.ac.jp/oai/junii2.xsd">';
-    $lines[] = $meta_basic;
-    $lines[] = '<NIItype>'.$textutil->xml_special_chars( xnpGetMetadataJunii2( 30 ) ).'</NIItype>';
-    $lines[] = '<type>simulatorType:'.$textutil->xml_special_chars( $detail['simulator_type']['value'] ).'</type>';
-    foreach ( $xnpsimulator->getVar( 'developer' ) as $developer ) {
-      $lines[] = '<creator>'.$textutil->xml_special_chars( $developer->getVar( 'developer', 'n' ) ).'</creator>';
-    }
-    $lines[] = "<date xsi:type=\"ISO8601\">".xnpISO8601( $basic->getVar( 'publication_year', 'n' ), $basic->getVar( 'publication_month', 'n' ), $basic->getVar( 'publication_mday', 'n' ) ).'</date>';
-    $lines[] = '<description>readme:'.$textutil->xml_special_chars( $detail['readme']['value'] ).'</description>';
-    $lines[] = '<description>rights:'.$textutil->xml_special_chars( $detail['rights']['value'] ).'</description>';
-    $lines[] = '</meta>';
-    $lines[] = '</metadata>';
-    return implode( "\n", $lines )."\n";
-  } else if ( $metadataPrefix == 'oai_dc' ) {
-    $lines = array();
-    $lines[] = '<metadata>';
-    $lines[] = '<oai_dc:dc 
-               xmlns:oai_dc="http://www.openarchives.org/OAI/2.0/oai_dc/" 
-               xmlns:dc="http://purl.org/dc/elements/1.1/" 
-               xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
-               xsi:schemaLocation="http://www.openarchives.org/OAI/2.0/oai_dc/ 
-               http://www.openarchives.org/OAI/2.0/oai_dc.xsd">';
-    $lines[] = $meta_basic;
-    $lines[] = '<dc:type>simulatorType:'.$textutil->xml_special_chars( $detail['simulator_type']['value'] ).'</dc:type>';
-    foreach ( $xnpsimulator->getVar( 'developer' ) as $developer ) {
-      $lines[] = '<dc:creator>'.$textutil->xml_special_chars( $developer->getVar( 'developer', 'n' ) ).'</dc:creator>';
-    }
-    $lines[] = '<dc:date>'.xnpISO8601( $basic->getVar( 'publication_year', 'n' ), $basic->getVar( 'publication_month', 'n' ), $basic->getVar( 'publication_mday', 'n' ) ).'</dc:date>';
-    $lines[] = '<dc:rights>'.$textutil->xml_special_chars( $detail['rights']['value'] ).'</dc:rights>';
-    $lines[] = '<dc:description>readme:'.$textutil->xml_special_chars( $detail['readme']['value'] ).'</dc:description>';
-    $lines[] = '</oai_dc:dc>';
-    $lines[] = '</metadata>';
-    return implode( "\n", $lines )."\n";
-  } else {
-    return false;
+  $previews = $file_handler->getFilesInfo($item_id, 'preview');
+  // rights
+  $detail['rights_cc_url'] = '';
+  if ($detail['use_cc'] == 1) {
+    $cond = 'by';
+    if ($detail['cc_commercial_use'] == 0)
+      $cond .= '-nc';
+    if ($detail['cc_modification'] == 0)
+      $cond .= '-nd';
+    else if ($detail['cc_modification'] == 1)
+      $cond .= '-sa';
+    $detail['rights_cc_url'] = sprintf('http://creativecommons.org/licenses/%s/2.5/', $cond);
   }
+  // related to
+  $related_to_handler =& xoonips_getormhandler('xoonips', 'related_to');
+  $related_to_ids = $related_to_handler->getChildItemIds($item_id);
+  $related_tos = array();
+  foreach ($related_to_ids as $related_to_id) {
+    $related_tos[] = array(
+      'item_id' => $related_to_id,
+      'item_url' => XOOPS_URL.'/modules/xoonips/detail.php?item_id='.$related_to_id
+    );
+  }
+  // repository configs
+  $xconfig_handler =& xoonips_getormhandler( 'xoonips', 'config' );
+  $myxoopsConfigMetaFooter =& xoonips_get_xoops_configs(XOOPS_CONF_METAFOOTER);
+  $repository = array(
+    'download_file_compression' => $xconfig_handler->getValue('download_file_compression'),
+    'nijc_code' => $xconfig_handler->getValue('repository_nijc_code'),
+    'publisher' => $xconfig_handler->getValue('repository_publisher'),
+    'institution' => $xconfig_handler->getValue('repository_institution'),
+    'meta_author' => $myxoopsConfigMetaFooter['meta_author']
+  );
+  // assign template
+  global $xoopsTpl;
+  $tpl = new XoopsTpl();
+  $tpl->plugins_dir[] = XOONIPS_PATH.'/class/smarty/plugins';
+  $tpl->assign($xoopsTpl->get_template_vars());
+  $tpl->assign('basic', $basic);
+  $tpl->assign('detail', $detail);
+  $tpl->assign('indexes', $indexes);
+  $tpl->assign('files', $files);
+  $tpl->assign('mimetypes', $mimetypes);
+  $tpl->assign('previews', $previews);
+  $tpl->assign('related_tos', $related_tos);
+  $tpl->assign('repository', $repository);
+  $xml = $tpl->fetch('db:'.$mydirname.'_oaipmh_'.$prefix.'.xml');
+  return $xml;
 }
-
-?>
