@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.1.4.1.2.15 $
+// $Revision: 1.1.4.1.2.17 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -68,7 +68,9 @@ function b_xoonips_tree_show() {
   if ( $current_script == $site_url_base.'user.php' ) {
     $op = $formdata->getValue( 'both', 'op', 's', false );
     if ( is_null( $op ) ) {
-      header( 'Location: modules/xoonips/user.php' );
+      $xoops_redirect = $formdata->getValue( 'get', 'xoops_redirect', 's', false );
+      $redirect = !empty($xoops_redirect) ? '?xoops_redirect='.urlencode($xoops_redirect) :'';
+      header( 'Location: modules/xoonips/user.php'.$redirect );
       exit();
     }
   }
