@@ -2,7 +2,7 @@
 
 //
 // customized Snoopy class for the XooNIps
-// $Revision: 1.1.2.4 $
+// $Revision: 1.1.2.7 $
 //
 if ( ! defined( 'XOOPS_ROOT_PATH' ) ) {
   exit();
@@ -93,7 +93,7 @@ class XooNIpsUtilitySnoopy extends XooNIpsUtility
 												// has permission to write to.
 												// under Windows, this should be C:\temp
 
-	var	$curl_path		=	"/usr/local/bin/curl";
+	var	$curl_path		=	"/usr/bin/curl";
 												// Snoopy will use cURL for fetching
 												// SSL content if a full system path to
 												// the cURL binary is supplied here.
@@ -147,6 +147,9 @@ class XooNIpsUtilitySnoopy extends XooNIpsUtility
 	      $this->proxy_pass = $proxy['proxy_pass'];
 	    }
 	  }
+	  // override curl path
+	  if ( defined('XOONIPS_CURL_PATH') )
+	    $this->curl_path = XOONIPS_CURL_PATH;
 	}
 
 /*======================================================================*\
@@ -1066,7 +1069,7 @@ class XooNIpsUtilitySnoopy extends XooNIpsUtility
 		
 		$headerfile = tempnam($temp_dir, "sno");
 
-		exec($this->curl_path." -k -D \"$headerfile\"".$cmdline_params." \"".escapeshellcmd($URI)."\"",$results,$return);
+		exec($this->curl_path." -k -D \"$headerfile\"".$cmdline_params." ".escapeshellarg($URI),$results,$return);
 		
 		if($return)
 		{
@@ -1108,7 +1111,11 @@ class XooNIpsUtilitySnoopy extends XooNIpsUtility
 			}
 		
 			if(preg_match("|^HTTP/|",$result_headers[$currentHeader]))
+			{
+				if(preg_match("|^HTTP/[^\s]*\s(.*?)\s|",$result_headers[$currentHeader], $status))
+					$this->status= $status[1];
 				$this->response_code = $result_headers[$currentHeader];
+			}
 
 			$this->headers[] = $result_headers[$currentHeader];
 		}
