@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.13.2.1.2.18 $
+// $Revision: 1.13.2.1.2.20 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -60,7 +60,7 @@ $uid = $_SESSION['xoopsUserId'];
 $itemtypes = array();
 if( xnp_get_item_types( $itemtypes ) != RES_OK ){
     redirect_header(XOOPS_URL.'/', 3, "ERROR xnp_get_item_types");
-    break;
+    exit();
 }else{
     foreach( $itemtypes as $i){
         if( $i['item_type_id'] == $item_type_id ){
@@ -70,6 +70,10 @@ if( xnp_get_item_types( $itemtypes ) != RES_OK ){
         }
     }
 }
+if ( ! isset( $itemtype ) ) {
+  redirect_header( XOOPS_URL.'/', 3, "ERROR item type not detected" );
+  exit();
+}
 
 //include view.php
 include_once XOOPS_ROOT_PATH . '/modules/' . $itemtype['viewphp'];
