@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.4.2.1.2.2 $
+// $Revision: 1.4.2.1.2.4 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -24,63 +24,19 @@
 //  along with this program; if not, write to the Free Software              //
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 // ------------------------------------------------------------------------- //
-define( 'READFILE_FAILED', 'cannot read file' );
-
-class XoonipsText extends XoonipsSearchTextExtractor {
-  function XoonipsText() {
-  }
-  
-  var $encode = false;
+/**
+ * file search plugin class for TEXT
+ */
+class XooNIpsFileSearchPluginTEXT extends XooNIpsFileSearchPlugin {
 
   /**
-   * extract text from file
-   *   @return extracted utf8 encoded string
+   * constractor
    */
-  function fetch() {
-    if ( $this->handle == false ) {
-      return array( false, XOONIPS_SEARCH_TEXT_FAILED );
-    }
-    
-    if ( $this->encode != false ) {
-      // already detected encoding
-      $line = fgets( $this->handle );
-      if ( $line == false ) {
-        $this->close();
-        
-        return array( false, false );
-      }
-      if ( $this->encode == 'UTF-8' ) {
-        return array( $line, false );
-      } else {
-        return array( mb_convert_encoding( $line, 'UTF-8', $this->encode ), false );
-      }
-    }
-    
-    // detect encoding
-    $len = 0;
-    $ar = array();
-    while ( $len < 65536 ) {
-      // todo: replaoce fgets() function for too long one-line text
-      $line = fgets( $this->handle );
-      if ( $line == false ) {
-        if ( count( $ar ) == 0 ) {
-          $this->close();
-          return array( false, false );
-        }
-        break;
-      }
-      $ar[] = $line;
-      $len += strlen( $line );
-    }
-    $text = implode( '', $ar );
-    $encode = strtolower( mb_detect_encoding( $text ) );
-    if ( $encode == 'ascii' ) {
-      return array( $text, false );
-    }
-    $this->encode = $encode;
-    
-    return array( mb_convert_encoding( $text, 'UTF-8', $this->encode ), false );
+  function XooNIpsFileSearchPluginTEXT() {
+    parent::XooNIpsFileSearchPlugin();
+    $this->is_xml = false;
+    $this->is_utf8 = false;
   }
-};
+}
 
 ?>
