@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.2.11 $
+// $Revision: 1.1.2.13 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
@@ -32,16 +32,10 @@ if (!defined('XOOPS_ROOT_PATH')) {
     exit();
 }
 
-foreach (array('checkbox' => 'off', 'add_to_index_id' => false, 
-    'jumpto_url' => '') as $k => $v) {
-    if (array_key_exists($k, $_GET)) {
-        $$k = $_GET[$k];
-    } elseif (array_key_exists($k, $_POST)) {
-        $$k = $_POST[$k];
-    } else {
-        $$k = $v;
-    }
-}
+$formdata =& xoonips_getutility( 'formdata' );
+$checkbox = $formdata->getValue('both', 'checkbox', 's', false, 'off');
+$add_to_index_id = $formdata->getValue('both', 'add_to_index_id', 'i', false, 0);
+$jumpto_url = $formdata->getValue('both', 'jumpto_url', 's', false, '');
 
 $item_type_handler =& xoonips_getormhandler( 'xoonips', 'item_type' );
 $itemtypes =& $item_type_handler->getObjectsSortByWeight();
@@ -69,7 +63,7 @@ if (!isset($pankuzu)) {
 
 $textutil =& xoonips_getutility( 'text' );
 
-$xoopsTpl->assign('itemselect_url', $itemselect_url);
+$xoopsTpl->assign('itemselect_url', $textutil->html_special_chars($itemselect_url));
 $xoopsTpl->assign('pankuzu', $pankuzu);
 $escaped_search_var=array();
 foreach( $search_var as $val ){
@@ -77,9 +71,9 @@ foreach( $search_var as $val ){
 }
 $xoopsTpl->assign('search_var',$escaped_search_var);
 $xoopsTpl->assign('search_blocks', $search_blocks);
-$xoopsTpl->assign('add_to_index_id', $add_to_index_id);
+$xoopsTpl->assign('add_to_index_id', intval($add_to_index_id));
 $xoopsTpl->assign('accept_charset', xnpGetMacSafariAcceptCharset());
 
-$xoopsTpl->assign('jumpto_url', $jumpto_url);
+$xoopsTpl->assign('jumpto_url', $textutil->html_special_chars($jumpto_url));
 
 ?>
