@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.104.2.1.2.31 $
+// $Revision: 1.104.2.1.2.36 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -26,17 +26,38 @@
 // ------------------------------------------------------------------------- //
 /**
  * constant strings
- * $Revision: 1.104.2.1.2.31 $
+ * $Revision: 1.104.2.1.2.36 $
  */
 
 // _MD_<MODULENAME>_<STRINGNAME>
 
-// labels
-define( '_MD_XOONIPS_LABEL_HOME', 'ۡ' );
-
 // font
 define( '_MD_XOONIPS_FONT_LANGUAGE', 'japanese' );
 
+// labels
+define( '_MD_XOONIPS_LABEL_HOME', 'ۡ' );
+define( '_MD_XOONIPS_LABEL_ADD', 'ɲ' );
+define( '_MD_XOONIPS_LABEL_MODIFY', 'Խ' );
+define( '_MD_XOONIPS_LABEL_DELETE', '' );
+define( '_MD_XOONIPS_LABEL_UPDATE', '' );
+define( '_MD_XOONIPS_LABEL_UPLOAD', 'åץ' );
+define( '_MD_XOONIPS_LABEL_NEXT', '' );
+define( '_MD_XOONIPS_LABEL_BACK', '' );
+define( '_MD_XOONIPS_LABEL_CANCEL', '󥻥' );
+define( '_MD_XOONIPS_LABEL_SUBMIT', '' );
+define( '_MD_XOONIPS_LABEL_ACTION', '' );
+define( '_MD_XOONIPS_LABEL_WEIGHT', '¤ӽ' );
+
+define( '_MD_XOONIPS_LABEL_ITEM_NUMBER_LIMIT', 'ϿǽʥƥκĿ' );
+define( '_MD_XOONIPS_LABEL_INDEX_NUMBER_LIMIT', 'ϿǽʥǥåκĿ' );
+define( '_MD_XOONIPS_LABEL_ITEM_STORAGE_LIMIT', 'Ͽǽʥƥκǥ[MB]' );
+
+define( '_MD_XOONIPS_LABEL_GROUP_NAME', '롼̾' );
+define( '_MD_XOONIPS_LABEL_GROUP_DESCRIPTION', '롼׾ܺ' );
+define( '_MD_XOONIPS_LABEL_GROUP_ADMINISTRATORS', '롼״' );
+define( '_MD_XOONIPS_LABEL_GROUP_MEMBERS', '롼ץС' );
+define( '_MD_XOONIPS_LABEL_GROUP_NUM_OF_ITEMS', 'ͭƥ' );
+
 define( "_MD_XOONIPS_ITEM_LISTING_ITEM", "ƥ" );
 define( "_MD_XOONIPS_ITEM_ORDER_BY", "¤ӽ : " );
 define( "_MD_XOONIPS_ITEM_NUM_OF_ITEM_PER_PAGE", "No.Item per page" );
@@ -207,23 +228,24 @@ define( '_MD_XOONIPS_RIGHTS_YES_SA', 'Ϥ¾ο͡ƱǶͭΤߡ' );
 define("_MD_XOONIPS_MODERATOR_SHULD_BE_MODERATOR"    ,"ΥꥢؤΥ¤ޤ󡥥ǥ졼¤ɬפˤʤޤ" );
 
 // groups
-define('_MD_XOONIPS_GROUPS_EMPTY','롼פϿƤޤ');
-
-// editgroups.php?op=
-define('_MD_XOONIPS_MODERATOR_GROUP_LIST','롼װ');
-define('_MD_XOONIPS_MODERATOR_GNAME','롼̾');
-define('_MD_XOONIPS_MODERATOR_GDESC','롼׾ܺ');
-define('_MD_XOONIPS_MODERATOR_ADMINISTRATOR','aministrator');
-define('_MD_XOONIPS_MODERATOR_OPERATION','');
-define('_MD_XOONIPS_MODERATOR_EDIT','Խ');
-define('_MD_XOONIPS_MODERATOR_DELETE','');
-define('_MD_XOONIPS_MODERATOR_GROUP_ADMIN','롼״');
-define('_MD_XOONIPS_MODERATOR_CREATE_GROUP','롼׺');
-define('_MD_XOONIPS_MODERATOR_EDIT_GROUP','롼Խ');
-define('_MD_XOONIPS_MODERATOR_REALLY_DELETE' ,'Υ롼פޤ?' );
-define('_MD_XOONIPS_MODERATOR_ITEM_STORAGE_LIMIT' ,'Ͽǽʥƥκǥ[MB]' );
-define('_MD_XOONIPS_MODERATOR_ITEM_NUMBER_LIMIT' ,'ϿǽʥƥκĿ' );
-define('_MD_XOONIPS_MODERATOR_INDEX_NUMBER_LIMIT' ,'ϿǽʥǥåκĿ' );
+define( '_MD_XOONIPS_TITLE_GROUP_LIST', '롼װ' );
+define( '_MD_XOONIPS_TITLE_GROUP_MEMBER_EDIT', '롼ץСԽ' );
+define( '_MD_XOONIPS_TITLE_GROUP_EDIT', '롼Խ' );
+define( '_MD_XOONIPS_TITLE_GROUP_CREATE', '롼׿' );
+define( '_MD_XOONIPS_MSG_GROUP_EMPTY', '롼פϿƤޤ' );
+define( '_MD_XOONIPS_MSG_GROUP_ENTER_NAME', '롼̾ϤƤ' );
+define( '_MD_XOONIPS_MSG_GROUP_ENTER_ADMINS', '롼״ԤϤƤ' );
+define( '_MD_XOONIPS_MSG_GROUP_DELETE_CONFIRM', 'ˤΥ롼פޤ?' );
+define( '_MD_XOONIPS_MSG_GROUP_NAME_EXISTS', 'Υ롼̾ϴ¸ߤޤ' );
+define( '_MD_XOONIPS_MSG_GROUP_NAME_FORBIDDEN', 'Υ롼̾ϻѤǤޤ' );
+define( '_MD_XOONIPS_LABEL_GROUPADMIN_MEMBERS', 'С' );
+define( '_MD_XOONIPS_LABEL_GROUPADMIN_NONMEMBERS', 'С' );
+define( '_MD_XOONIPS_LABEL_GROUPADMIN_ADD', 'ɲ --&gt;' );
+define( '_MD_XOONIPS_LABEL_GROUPADMIN_DELETE', '&lt;-- ' );
+define( '_MD_XOONIPS_ERROR_GROUP_SELECT', '롼פμ˼Ԥޤ' );
+define( '_MD_XOONIPS_ERROR_GROUP_INSERT', '롼פϿ˼Ԥޤ' );
+define( '_MD_XOONIPS_ERROR_GROUP_UPDATE', '롼פι˼Ԥޤ' );
+define( '_MD_XOONIPS_ERROR_GROUP_DELETE', '롼פκ˼Ԥޤ' );
 
 // certify.php
 define('_MD_XOONIPS_MODERATOR_CERTIFY_USER','桼ǧ');
@@ -235,24 +257,15 @@ define('_MD_XOONIPS_MODERATOR_UNCERTIFY','');
 define('_MD_XOONIPS_MODERATOR_UNCERTIFY_CANCEL_LABEL','');
 define('_MD_XOONIPS_MODERATOR_UNCERTIFY_EXECUTE_LABEL','¹');
 define('_MD_XOONIPS_MODERATOR_UNCERTIFY_TITLE','桼ǧݳǧ');
-define('_MD_XOONIPS_MODERATOR_UNCERTIFY_DESC','桼Ͽݤޤ<br />ͳϰʲˤλݤ񤤤Ƥ');
+define('_MD_XOONIPS_MODERATOR_UNCERTIFY_DESC','桼Ͽݤޤ<br />ͳʲˤ񤭤');
 define('_MD_XOONIPS_MODERATOR_UNCERTIFY_SUCCESS','桼Ͽεݤλޤ');
 define("_MD_XOONIPS_MODERATOR_ERROR_SELECT_USER"    ,"桼λ꤬Ǥ" );
 
-define("_MD_XOONIPS_MODERATOR_ENTER_GROUP_NAME"    ,"롼̾ϤƤ" );
-define("_MD_XOONIPS_MODERATOR_ERROR_INSERT_GROUP"    ,"롼פϿ˼Ԥޤ" );
-define("_MD_XOONIPS_MODERATOR_ERROR_SELECT_GROUP"    ,"롼פμ˼Ԥޤ" );
-define("_MD_XOONIPS_MODERATOR_ERROR_DELETE_GROUP"    ,"롼פκ˼Ԥޤ" );
 
 define("_MD_XOONIPS_MODERATOR_NOT_ACTIVATED"    ,"ǧƤʤᥢǤޤ" );
 define("_MD_XOONIPS_MODERATOR_NO_CERTIFY_USERS"    ,"ǧԤΥ桼Ϥޤ" );
 
 define("_MD_XOONIPS_MODERATOR_PANKUZU_CERTIFY_USERS", "桼ǧ" );
-define("_MD_XOONIPS_MODERATOR_PANKUZU_EDIT_GROUPS", "롼Խ" );
-define("_MD_XOONIPS_MODERATOR_PANKUZU_CREATE_NEW_GROUPS", "롼׿" );
-
-define("_MD_XOONIPS_GROUPNAME_ALREADY_EXISTS", "Υ롼̾ϴ¸ߤޤ" );
-define("_MD_XOONIPS_GROUPNAME_FORBIDDEN"    ,"Υ롼̾ϻѤǤޤ" );
 define("_MD_XOONIPS_USER_CERTIFICATION_SUCCEED", "桼ǧޤ" );
 
 /// following defines for index
@@ -304,7 +317,7 @@ define('_MD_XOONIPS_ACCOUNT_DSN_EMPTY','xoonips  dsn ꤵƤޤ');
 
 //labels of register/edit account items
 define("_MD_XOONIPS_ACCOUNT_ADDRESS", "" );
-define("_MD_XOONIPS_ACCOUNT_DIVISION", "°" );
+define("_MD_XOONIPS_ACCOUNT_DIVISION", "/漼" );
 define("_MD_XOONIPS_ACCOUNT_TEL", "ֹ" );
 define("_MD_XOONIPS_ACCOUNT_FAX", "FAXֹ" );
 define("_MD_XOONIPS_ACCOUNT_COMPANY_NAME", "̾/̾/̾" );
@@ -332,7 +345,7 @@ define("_MD_XOONIPS_ACCOUNT_NOTIFICATIONS", "٥εǽ" );
 
 // register.php errormessage
 define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_ADDRESS"     ,""                           . "Ĺޤ127ʸʲˤƲ");
-define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_DIVISION"    ,"°"                          . "Ĺޤ127ʸʲˤƲ");
+define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_DIVISION"    ,"/漼"                          . "Ĺޤ127ʸʲˤƲ");
 define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_TEL"         ,"ֹ"                          . "ĹޤȾ32ʸʲˤƲ");
 define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_COMPANY_NAME","FAXֹ"                            . "ĹޤȾ32ʸʲˤƲ");
 define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_ZIPCODE"     ,"͹ֹ"                          . "Ĺޤ127ʸʲˤƲ");
@@ -347,15 +360,6 @@ define("_MD_XOONIPS_ACCOUNT_INVITE_USER_MAIL_SUBJECT"    ,"ҲΤΤ餻 " );
 define("_MD_XOONIPS_ACCOUNT_CANNOT_ACQUIRE_USER_INFO", "桼μ˼Ԥޤ" );
 define("_MD_XOONIPS_ACCOUNT_CANNOT_UPDATE_USER_INFO" , "桼ι˼Ԥޤ" );
 
-// groupadmin.php
-define("_MD_XOONIPS_ACCOUNT_GROUPADMIN"                 ,"롼״");
-define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_GROUP_LIST"      ,"롼װ");
-define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_MEMBERS"         ,"С");
-define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_NON_MEMBERS"     ,"С");
-define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_ADD_BUTTON"      ,"ɲ --&gt;");
-define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_DELETE_BUTTON"   ,"&lt;-- ");
-define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_NO_EDITABLE_GROUPS"        ,"ǽʥ롼פϤޤ");
-
 define("_MD_XOONIPS_ACCOUNT_QUERY_ERROR"    ,"ǡ١Υꥨ顼Ǥ" );
 
 define("_MD_XOONIPS_ACCOUNT_FORBIDDEN"    ,"ΥꥢؤΥϵĤƤޤ" );
@@ -404,6 +408,7 @@ define("_MD_XOONIPS_ACCOUNT_ACTIVATE_NG", "Ȥ򥢥ƥ١ȤǤޤǤԤӥǥ졼䤤碌Ƥ"
 
 //subjects for e-mail of user registration
 define("_MD_XOONIPS_ACCOUNT_CERTIFIED", 'Ȥξǧλޤ' );
+define("_MD_XOONIPS_ACCOUNT_REJECTED", 'Ȥǧݤޤ' );
 define('_MD_XOONIPS_ACCOUNT_REGISTERD','桼ǧƤ');
 
 
@@ -506,7 +511,6 @@ define( '_MI_XOONIPS_ACCOUNT_PANKUZU_PLATFORM_USER', '桼' );
 define( '_MI_XOONIPS_ACCOUNT_PANKUZU_GROUP_ADMINISTRATOR', '롼״' );
 define( '_MI_XOONIPS_ACCOUNT_PANKUZU_MODERATOR', 'ǥ졼' );
 define( '_MI_XOONIPS_ACCOUNT_PANKUZU_SEPARATOR', '&nbsp;&raquo;&raquo;&nbsp;' );
-define( '_MI_XOONIPS_ACCOUNT_PANKUZU_EDIT_GROUPS', '롼Խ' );
 define( '_MI_XOONIPS_ITEM_PANKUZU_CERTIFY_PUBLIC_ITEMS', 'ƥྵǧ' );
 define( '_MI_XOONIPS_ITEM_PANKUZU_CERTIFY_GROUP_ITEMS', '롼׸ƥྵǧ' );
 define( '_MI_XOONIPS_ITEM_PANKUZU_EDIT_ACCOUNT', 'ץեԽ' );
@@ -727,6 +731,7 @@ define( "_MD_XOONIPS_IMPORT_CONFLICT_ITEMS_LOCKED_TRANSFER_REQUEST", "Ʊǥå˰ʲ
 define( "_MD_XOONIPS_ITEM_TRANSFER_NOTIFYSBJ", "ƥबܾޤ" );
 define( "_MD_XOONIPS_ACCOUNT_CERTIFY_REQUEST_NOTIFYSBJ", "ȤϿޤ" );
 define( "_MD_XOONIPS_ACCOUNT_CERTIFIED_NOTIFYSBJ", "Ȥǧޤ" );
+define( "_MD_XOONIPS_ACCOUNT_REJECTED_NOTIFYSBJ", "Ȥǧݤޤ" );
 define( "_MD_XOONIPS_ITEM_CERTIFY_REQUEST_NOTIFYSBJ", "ǧԤΥƥबޤ" );
 define( "_MD_XOONIPS_ITEM_CERTIFIED_AUTO_NOTIFYSBJ", "ƥबưǧޤ" );
 define( "_MD_XOONIPS_ITEM_CERTIFIED_NOTIFYSBJ", "ƥबǧޤ" );
@@ -879,15 +884,12 @@ define( '_MD_XOONIPS_OAIPMH_METADATA_DETAIL_BACK', '' );
 
 // breadcrumbs
 define( '_MD_XOONIPS_BREADCRUMBS_USER', '桼' );
-define( '_MD_XOONIPS_BREADCRUMBS_GROUP', '롼' );
+define( '_MD_XOONIPS_BREADCRUMBS_GROUPADMIN', '롼״' );
 define( '_MD_XOONIPS_BREADCRUMBS_MODERATOR', 'ǥ졼' );
 // - event_log.php
 define( '_MD_XOONIPS_BREADCRUMBS_EVENTLOG', '٥ȥ' );
 define( '_MD_XOONIPS_BREADCRUMBS_EVENTLOG_GRAPH', 'ץ' );
 define( '_MD_XOONIPS_BREADCRUMBS_EVENTLOG_LIST', 'Ͽ' );
-// - groups.php
-define( '_MD_XOONIPS_BREADCRUMBS_GROUPS_LIST', '롼װ' );
-
 
 //// 200801 add ////
 define( "_MD_XOONIPS_ITEM_GROUP_CERTIFY_ITEM_TITLE", "롼ץƥྵǧ" );
